@@ -1,5 +1,6 @@
-mod pages;
+mod image_page;
 mod paginator;
-mod window;
 
+mod window;
+pub use image_page::ImagePageWidget;
 pub use window::Window;
